!! Test the Savitzky-Golay filter module with a sonic log

program SG_test
	use sep
	use auxsu
	use Savitzky_Golay

	implicit none

	integer :: i,j,m,nl,nr,stat,ld,wrp,np,nlyr
	real,dimension(:),allocatable :: vel1,vel2,c,tmp

	!! hook up SEP stuff
	call sep_init()

	call from_param("nlyr",nlyr,99)
	call from_param("nl",nl,16)
	call from_param("nr",nr,16)
	call from_param("np",np,nl+nr+1)
	call from_param("m",m,4)
	call from_param("ld",ld,0)
	call from_param("wrp",wrp,0)

	!! allocate working arrays
	allocate(vel1(nlyr),vel2(nlyr+nl+nr),c(nl+nr+1),tmp(nlyr+nl+nr))

	!! compute Savitzky-Golay filter coefficients
	call savgol(c,np,nl,nr,ld,m,wrp)
	
	!! open file to read data to be smoothed
	open(unit=10,file='layer.txt',status='old',action='read',iostat=stat)
	if (stat/=0) then
		write(0,*)'ERROR: could not open file layer.txt'
		stop
	end if

	!! read in the data
	do j=1,nlyr
		read(10,*) vel1(j)
	end do

	!! extend the data off the sides so that the filter does not find null
	!! data
	tmp(1:nl)=vel1(1)
	tmp(nl+nlyr+1:)=vel1(nlyr)
	tmp(nl+1:nlyr+nl)=vel1(1:nlyr)

	!! convolve data with filter
	!call convsu(nl+nr+1,-nl,c,nlyr,1,vel1,nlyr+nl+nr,-nl+1,vel2)
	call convsu(nl+nr+1,-nl,c,nlyr+nl+nr,1,tmp,nlyr+nl+nr,-nl+1,vel2)

	!! write parameters to output header file
	call to_history("n1",nlyr)
	call to_history("o1",0)
	call to_history("d1",10)
	call to_history("n2",1)
	call to_history("n3",1)
	call to_history("esize",4)

	call to_history("n1",nlyr,"aux")
	call to_history("o1",0,"aux")
	call to_history("d1",10,"aux")
	call to_history("n2",1,"aux")
	call to_history("n3",1,"aux")
	call to_history("esize",4,"aux")
	
	call sep_close()

	!! write out original and smoothed data as history files
	call srite("out",vel2(2*nl:nlyr+2*nl-1),4*size(vel1))
	call srite("junk.H",vel2,4*size(vel2))
	call srite("aux",vel1,4*size(vel1))

	!! deallocate working arrays
	deallocate(c,vel1,vel2,tmp)

end program SG_test
