!! compute the number of possibilities of each gene for the genetic algorithm
!! velocity inversion problem

program nposibl
	use sep

	implicit none

	integer :: i,ngenes,pad
	real	:: max,min,resolution,delta
	real,dimension(:),allocatable :: trend
	integer,dimension(:),allocatable :: ngen_pos

	!! hook up SEP stuff
	call sep_init()

	!! get command line parameters
	call from_param("ngenes",ngenes,99)
	call from_param("max",max,20.)
	call from_param("min",min,20.)
	call from_param("resolution",resolution,1.)

	!! compute velocity sampling
	max=1.+max/100.
	min=1.-min/100.
	delta=(max-min)/resolution

	!! allocate working array
	allocate(trend(ngenes),ngen_pos(ngenes))

	!! read in input data
	call sreed("in",trend,4*size(trend))

	!! write parameters to output header file
	call to_history("n1",ngenes)
	call to_history("n2",1)
	call to_history("n3",1)
	call to_history("o1",0)
	call to_history("d1",10)
	call sep_close()

	!! compute the number of possibilities of each gene
	!! in this case this means number of velocities between maximum
	!! (max*trend) and minimum (min*trend) for the given resolution
	!! write out original and smoothed data as history files
	ngen_pos=INT(delta*trend)

	!! make sure that the number of possibilities are a power of 2
	do i=1,ngenes
		pad=1
		do
			if (pad >= ngen_pos(i)) exit
			pad=pad*2
		end do
		ngen_pos(i)=pad
		!write(0,*)'i=',i,'nposibl=',ngen_pos(i)
	end do

	call srite("out",float(ngen_pos),4*size(ngen_pos))

	!! deallocate working array
	deallocate(ngen_pos)

end program nposibl
